summaryrefslogtreecommitdiff
path: root/src/verify.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2021-04-10 23:54:31 +0200
committerCarl Hetherington <cth@carlh.net>2021-04-10 23:54:31 +0200
commit093525165f6397ba9eaffd19833dc978bcb32d55 (patch)
tree5a7a1a428aff635d9be44ea9af993ac83d71fc0f /src/verify.cc
parentc59e6c0e64f95afc7c33168e7c7562502411bd01 (diff)
Rename ReelFileAsset -> ReelEncryptableAsset
Diffstat (limited to 'src/verify.cc')
-rw-r--r--src/verify.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/verify.cc b/src/verify.cc
index ce79bc2e..e27f6f36 100644
--- a/src/verify.cc
+++ b/src/verify.cc
@@ -377,7 +377,7 @@ enum class VerifyAssetResult {
static VerifyAssetResult
-verify_asset (shared_ptr<const DCP> dcp, shared_ptr<const ReelFileAsset> reel_file_asset, function<void (float)> progress)
+verify_asset (shared_ptr<const DCP> dcp, shared_ptr<const ReelEncryptableAsset> reel_file_asset, function<void (float)> progress)
{
auto const actual_hash = reel_file_asset->asset_ref()->hash(progress);
@@ -422,7 +422,7 @@ verify_language_tag (string tag, vector<VerificationNote>& notes)
static void
-verify_picture_asset (shared_ptr<const ReelFileAsset> reel_file_asset, boost::filesystem::path file, vector<VerificationNote>& notes, function<void (float)> progress)
+verify_picture_asset (shared_ptr<const ReelEncryptableAsset> reel_file_asset, boost::filesystem::path file, vector<VerificationNote>& notes, function<void (float)> progress)
{
int biggest_frame = 0;
auto asset = dynamic_pointer_cast<PictureAsset>(reel_file_asset->asset_ref().asset());
@@ -1081,8 +1081,8 @@ pkl_has_encrypted_assets (shared_ptr<DCP> dcp, shared_ptr<PKL> pkl)
for (auto j: i->reel_file_assets()) {
if (j->asset_ref().resolved()) {
/* It's a bit surprising / broken but Interop subtitle assets are represented
* in reels by ReelSubtitleAsset which inherits ReelFileAsset, so it's possible for
* ReelFileAssets to have assets which are not MXFs.
*/
if (auto asset = dynamic_pointer_cast<MXF>(j->asset_ref().asset())) {
if (asset->encrypted()) {
@@ -1233,7 +1233,7 @@ dcp::verify (
if ((i->intrinsic_duration() * i->edit_rate().denominator / i->edit_rate().numerator) < 1) {
notes.push_back ({VerificationNote::Type::ERROR, VerificationNote::Code::INVALID_INTRINSIC_DURATION, i->id()});
}
- auto file_asset = dynamic_pointer_cast<ReelFileAsset>(i);
+ auto file_asset = dynamic_pointer_cast<ReelEncryptableAsset>(i);
if (file_asset && !file_asset->hash()) {
notes.push_back ({VerificationNote::Type::BV21_ERROR, VerificationNote::Code::MISSING_HASH, i->id()});
}
@@ -1081,8 +1081,8 @@ pkl_has_encrypted_assets (shared_ptr<DCP> dcp, shared_ptr<PKL> pkl)
if (j->asset_ref().resolved()) {
/* It's a bit surprising / broken but Interop subtitle assets are represented
- * in reels by ReelSubtitleAsset which inherits ReelFileAsset, so it's possible for
- * ReelFileAssets to have assets which are not MXFs.
+ * in reels by ReelSubtitleAsset which inherits ReelEncryptableAsset, so it's possible for
+ * ReelEncryptableAssets to have assets which are not MXFs.
*/
if (auto asset = dynamic_pointer_cast<MXF>(j->asset_ref().asset())) {